==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/ENTITYKEYENTRIES_Type.java <==

package net.datastream.schemas.mp_fields;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ENTITYKEYENTRIES_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ENTITYKEYENTRIES_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITYKEYENTRY" maxOccurs="10"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ENTITYKEYENTRIES_Type", propOrder = {
    "entitykeyentry"
})
public class ENTITYKEYENTRIES_Type {

    @XmlElement(name = "ENTITYKEYENTRY", required = true)
    protected List<ENTITYKEYENTRY> entitykeyentry;

    /**
     * Gets the value of the entitykeyentry property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the entitykeyentry property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getENTITYKEYENTRY().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ENTITYKEYENTRY }
     * 
     * 
     */
    public List<ENTITYKEYENTRY> getENTITYKEYENTRY() {
        if (entitykeyentry == null) {
            entitykeyentry = new ArrayList<ENTITYKEYENTRY>();
        }
        return this.entitykeyentry;
    }

}

==> eam-wshub-proxyclient-11.5-10-sources.jar: net/datastream/schemas/mp_fields/ENTITYKEYENTRIES_Type.java <==

package net.datastream.schemas.mp_fields;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ENTITYKEYENTRIES_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ENTITYKEYENTRIES_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITYKEYENTRY" maxOccurs="10"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ENTITYKEYENTRIES_Type", propOrder = {
    "entitykeyentry"
})
public class ENTITYKEYENTRIES_Type {

    @XmlElement(name = "ENTITYKEYENTRY", required = true)
    protected List<ENTITYKEYENTRY> entitykeyentry;

    /**
     * Gets the value of the entitykeyentry property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the entitykeyentry property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getENTITYKEYENTRY().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ENTITYKEYENTRY }
     * 
     * 
     */
    public List<ENTITYKEYENTRY> getENTITYKEYENTRY() {
        if (entitykeyentry == null) {
            entitykeyentry = new ArrayList<ENTITYKEYENTRY>();
        }
        return this.entitykeyentry;
    }

}
